==> rucy-0.4.0.tar.gz: rucy-0.4.0/control/AliasMap/AliasMap.rb <==
# $Id: AliasMap.rb,v 1.4 2004/12/31 12:34:50 toki Exp $

require 'forwardable'

class AliasMap < WPM::PageContext
  extend Forwardable

  def init_context
    @control = page_option(:control)
    @list = @control.aliases
    @alist = nil
    @index = nil
  end

  def_delegator :@list, :modified_count
  def_delegator :@list, :modified_count=

  def has_aliases?
    ! @list.empty?
  end

  def alias_list
    list = Array.new
    @list.each_with_index do |params, i|
      list.push({ :params => params, :pos => i })
    end

    list
  end

  attr_accessor :alias
  attr_accessor :index
  def_delegator '@alias[:params]', :alias_path
  def_delegator '@alias[:params]', :orig_path
  def_delegator '@alias[:params]', :virtual_host

  def up
    pos = @alias[:pos]
    if (1 <= pos && pos <= @list.length - 1) then
      @list.swap(pos, pos - 1)
      @control.set_aliases(@list)
      @alias[:pos] = pos - 1
    end

    nil
  end

  def down
    pos = @alias[:pos]
    if (0 <= pos && pos <= @list.length - 2) then
      @list.swap(pos, pos + 1)
      @control.set_aliases(@list)
      @alias[:pos] = pos + 1
    end

    nil
  end

  def up_disabled?
    @alias[:pos] <= 0
  end

  def down_disabled?
    @alias[:pos] >= @list.length - 1
  end

  def edit
    driver.redirect('SetupAlias', { 'pos' => @alias[:pos].to_s })
    nil
  end

  def add
    driver.redirect('SetupAlias', { 'pos' => @list.length.to_s })
    nil
  end

  def del
    pos = @alias[:pos]
    if (0 <= pos && pos <= @list.length - 1) then
      @list.delete_at(pos)
      @control.set_aliases(@list)
    end

    nil
  end
end

==> rucy-0.5.0.tar.gz: rucy-0.5.0/control/AliasMap/AliasMap.rb <==
# $Id: AliasMap.rb,v 1.5 2005/01/16 11:27:48 toki Exp $

require 'forwardable'

class AliasMap < WPM::PageContext
  extend Forwardable

  def init_context
    @control = page_option(:control)
    @list = @control.aliases
    @alist = nil
    @index = nil
  end

  def_delegator :@list, :modified_count
  def_delegator :@list, :modified_count=

  def has_aliases?
    ! @list.empty?
  end

  def alias_list
    list = Array.new
    @list.each_with_index do |params, i|
      list.push({ :params => params, :pos => i })
    end

    list
  end

  attr_accessor :alias
  attr_accessor :index

  def __alias__
    @alias[:params]
  end
  private :__alias__

  def_delegator :__alias__, :alias_path
  def_delegator :__alias__, :orig_path
  def_delegator :__alias__, :virtual_host

  def up
    pos = @alias[:pos]
    if (1 <= pos && pos <= @list.length - 1) then
      @list.swap(pos, pos - 1)
      @control.set_aliases(@list)
      @alias[:pos] = pos - 1
    end

    nil
  end

  def down
    pos = @alias[:pos]
    if (0 <= pos && pos <= @list.length - 2) then
      @list.swap(pos, pos + 1)
      @control.set_aliases(@list)
      @alias[:pos] = pos + 1
    end

    nil
  end

  def up_disabled?
    @alias[:pos] <= 0
  end

  def down_disabled?
    @alias[:pos] >= @list.length - 1
  end

  def edit
    driver.redirect('SetupAlias', { 'pos' => @alias[:pos].to_s })
    nil
  end

  def add
    driver.redirect('SetupAlias', { 'pos' => @list.length.to_s })
    nil
  end

  def del
    pos = @alias[:pos]
    if (0 <= pos && pos <= @list.length - 1) then
      @list.delete_at(pos)
      @control.set_aliases(@list)
    end

    nil
  end
end
